@@ -6,8 +6,6 @@ Public interface for the Assessment Workflow.
 
 import logging
 
-import six
-
 from django.db import DatabaseError
 
 from submissions import api as sub_api
@@ -346,7 +344,7 @@ def _get_workflow_model(submission_uuid):
             problem.
 
     """
-    if not isinstance(submission_uuid, six.string_types):
+    if not isinstance(submission_uuid, str):
         raise AssessmentWorkflowRequestError("submission_uuid must be a string type")
 
     try:
